@@ -19,14 +19,18 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <common.h>
+#include <arpa/inet.h>    // ntohl().
+#include <t50_config.h>
+#include <t50_defines.h>
+#include <t50_cidr.h>
+#include <t50_errors.h>
 
 static struct cidr cidr = {0};
 
 /**
  * CIDR configuration tiny C algorithm.
  *
- * This will setup cidr structure with values in host order. 
+ * This will setup cidr structure with values in host order.
  *
  * @param bits Number of "valid" bits on netmask.
  * @param address IP address from command line (in network order).
@@ -81,7 +85,7 @@ struct cidr *config_cidr(const struct config_options * const __restrict__ co)
     // This will work as if 32 bits.
     // 31 bits: 0
     //
-    // hostid == 0 means: use the address as is!
+    // hostid == 0 means: use the address as it is!
     //
     cidr.hostid = (1U << (32 - co->bits)) - 2U;
 
@@ -101,7 +105,7 @@ struct cidr *config_cidr(const struct config_options * const __restrict__ co)
   }
   else
   {
-    cidr.hostid = 0;    // means "no random address".
+    cidr.hostid = 0;    // means "not random address".
     cidr.__1st_addr = ntohl(co->ip.daddr);
   }
 
